#
# spec file for package vala
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           vala
Version:        0.32.1
Release:        3.3
%define         vala_version 0.32
%define         vala_libversion 0_32
# The priority defines which version of vala, in case of multiple ones are installed
# is to be used by default. The rule-of-thumb for vala is to use MAJORMINOR without
# decimal separator, hoping they will not get to the idea to create a 0.100 release.
%define         vala_priority 32
Summary:        Programming language for GNOME
License:        LGPL-2.0
Group:          Development/Languages/Other
Url:            http://live.gnome.org/Vala
Source0:        http://download.gnome.org/sources/vala/0.32/%{name}-%{version}.tar.xz
BuildRequires:  bison
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  glib2-devel >= 2.32.0
BuildRequires:  xsltproc
Requires(post): update-alternatives
Requires(postun): update-alternatives
# Vala is a compiler, so it's also a devel package
Provides:       vala-devel = %{version}
Obsoletes:      vala-devel < %{version}
# provide generic pkgconfig(vapigen) instead of -version one; not auto-detected due to %{_datadir}/pkgconfig/vapigen.pc being %ghost
Provides:       pkgconfig(vapigen) = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Vala is a new programming language that aims to bring modern
programming language features to GNOME developers without imposing any
additional runtime requirements and without using a different ABI
compared to applications and libraries written in C.

%package -n libvala-%{vala_libversion}-0
Summary:        Programming language for GNOME
Group:          System/Libraries

%description -n libvala-%{vala_libversion}-0
Vala is a new programming language that aims to bring modern
programming language features to GNOME developers without imposing any
additional runtime requirements and without using a different ABI
compared to applications and libraries written in C.

%package -n libvala-%{vala_libversion}-devel
Summary:        Programming language for GNOME
Group:          Development/Libraries/Other
Requires:       libvala-%{vala_libversion}-0 = %{version}

%description -n libvala-%{vala_libversion}-devel
Vala is a new programming language that aims to bring modern
programming language features to GNOME developers without imposing any
additional runtime requirements and without using a different ABI
compared to applications and libraries written in C.

%prep
%setup -q

%build
%configure --with-pic --enable-vapigen
make %{?jobs:-j%jobs}

%install
%makeinstall
find %{buildroot}%{_libdir} -type f -name '*.la' -delete -print
# Setup update-alternatives
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
ln -s -f %{_sysconfdir}/alternatives/vala %{buildroot}%{_bindir}/vala
ln -s -f %{_sysconfdir}/alternatives/valac %{buildroot}%{_bindir}/valac
ln -s -f %{_sysconfdir}/alternatives/vala-gen-introspect %{buildroot}%{_bindir}/vala-gen-introspect
ln -s -f %{_sysconfdir}/alternatives/vapicheck %{buildroot}%{_bindir}/vapicheck
ln -s -f %{_sysconfdir}/alternatives/vapigen %{buildroot}%{_bindir}/vapigen
ln -s -f %{_sysconfdir}/alternatives/valac.1.gz %{buildroot}%{_mandir}/man1/valac.1.gz
ln -s -f %{_sysconfdir}/alternatives/vala-gen-introspect.1.gz %{buildroot}%{_mandir}/man1/vala-gen-introspect.1.gz
ln -s -f %{_sysconfdir}/alternatives/vapigen.1.gz %{buildroot}%{_mandir}/man1/vapigen.1.gz
ln -s -f %{_sysconfdir}/alternatives/vapigen.pc %{buildroot}%{_datadir}/pkgconfig/vapigen.pc
%fdupes %{buildroot}%{_datadir}

%post
update-alternatives \
  --install %{_bindir}/vala                          vala                     %{_bindir}/vala-%{vala_version} \
            %{vala_priority} \
  --slave   %{_bindir}/valac                         valac                    %{_bindir}/valac-%{vala_version} \
  --slave   %{_bindir}/vala-gen-introspect           vala-gen-introspect      %{_bindir}/vala-gen-introspect-%{vala_version} \
  --slave   %{_bindir}/vapicheck                     vapicheck                %{_bindir}/vapicheck-%{vala_version} \
  --slave   %{_bindir}/vapigen                       vapigen                  %{_bindir}/vapigen-%{vala_version} \
  --slave   %{_mandir}/man1/valac.1.gz               valac.1.gz               %{_mandir}/man1/valac-%{vala_version}.1.gz \
  --slave   %{_mandir}/man1/vala-gen-introspect.1.gz vala-gen-introspect.1.gz %{_mandir}/man1/vala-gen-introspect-%{vala_version}.1.gz \
  --slave   %{_mandir}/man1/vapigen.1.gz             vapigen.1.gz             %{_mandir}/man1/vapigen-%{vala_version}.1.gz \
  --slave   %{_datadir}/pkgconfig/vapigen.pc         vapigen.pc               %{_datadir}/pkgconfig/vapigen-%{vala_version}.pc

%postun
# Note: we don't use "$1 -eq 0", to avoid issues if the package gets renamed
if [ ! -f %{_bindir}/vala-%{vala_version} ]; then
  update-alternatives --remove vala %{_bindir}/vala-%{vala_version}
fi

%post -n libvala-%{vala_libversion}-0 -p /sbin/ldconfig

%postun -n libvala-%{vala_libversion}-0 -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING NEWS README
%{_bindir}/vala
%{_bindir}/valac
%{_bindir}/vala-gen-introspect
%{_bindir}/vapicheck
%{_bindir}/vapigen
%{_mandir}/man1/valac.1*
%{_mandir}/man1/vala-gen-introspect.1*
%{_mandir}/man1/vapigen.1*
%{_datadir}/pkgconfig/vapigen.pc
%ghost %attr(755,root,root) %{_sysconfdir}/alternatives/vala
%ghost %attr(755,root,root) %{_sysconfdir}/alternatives/valac
%ghost %attr(755,root,root) %{_sysconfdir}/alternatives/vala-gen-introspect
%ghost %attr(755,root,root) %{_sysconfdir}/alternatives/vapicheck
%ghost %attr(755,root,root) %{_sysconfdir}/alternatives/vapigen
%ghost %attr(644,root,root) %{_sysconfdir}/alternatives/valac.1.gz
%ghost %attr(644,root,root) %{_sysconfdir}/alternatives/vala-gen-introspect.1.gz
%ghost %attr(644,root,root) %{_sysconfdir}/alternatives/vapigen.1.gz
%ghost %attr(644,root,root) %{_sysconfdir}/alternatives/vapigen.pc
%{_bindir}/vala-%{vala_version}
%{_bindir}/valac-%{vala_version}
%{_bindir}/vala-gen-introspect-%{vala_version}
%{_bindir}/vapicheck-%{vala_version}
%{_bindir}/vapigen-%{vala_version}
%{_mandir}/man1/valac-%{vala_version}.1*
%{_mandir}/man1/vala-gen-introspect-%{vala_version}.1*
%{_mandir}/man1/vapigen-%{vala_version}.1*
%{_datadir}/aclocal/vala.m4
%{_datadir}/aclocal/vapigen.m4
%{_datadir}/pkgconfig/vapigen-%{vala_version}.pc
%dir %{_datadir}/vala
%{_datadir}/vala/Makefile.vapigen
%{_datadir}/vala-%{vala_version}/
%{_libdir}/vala-%{vala_version}/

%files -n libvala-%{vala_libversion}-0
%defattr(-,root,root,-)
%{_libdir}/libvala-%{vala_version}.so.*

%files -n libvala-%{vala_libversion}-devel
%defattr(-,root,root,-)
%{_includedir}/vala-%{vala_version}/
%{_libdir}/libvala-%{vala_version}.so
%{_libdir}/pkgconfig/libvala-%{vala_version}.pc
%dir %{_datadir}/devhelp/
%dir %{_datadir}/devhelp/books/
%{_datadir}/devhelp/books/%{name}-%{vala_version}/

%changelog
* Mon Jun 20 2016 zaitor@opensuse.org
- Update to version 0.32.1:
  + Bug fixes and binding updates.
* Mon Mar 21 2016 dimstar@opensuse.org
- Update to version 0.32.0:
  + Bug fixes and binding updates.
* Mon Feb  8 2016 dimstar@opensuse.org
- Update to version 0.31.1:
  + Introduce [Version] attribute.
  + Require and target GLib >= 2.32.
  + Bug fixes and binding updates.
- Bump vala_version to 0.32, vala_libversion to 0_32 (following
  upstream) and vala_priority to 32 (following the vala packaging
  convention).
* Mon Feb  1 2016 dimstar@opensuse.org
- Update to version 0.30.1:
  + Bug fixes and binding updates.
* Fri Sep 18 2015 dimstar@opensuse.org
- Update to version 0.30.0:
  + Binding updates.
  + Bugs fixed: bgo#752031.
- Bump vala_priority to 30.
* Tue Aug 11 2015 zaitor@opensuse.org
- Update to version 0.29.3:
  + Add --shared-library option for GIR files.
  + Bug fixes and binding updates.
* Tue Aug 11 2015 zaitor@opensuse.org
- Update to version 0.29.2:
  + Bug fixes and binding updates.
* Tue Aug 11 2015 zaitor@opensuse.org
- Update to version 0.29.1:
  + Binding updates.
* Tue Aug 11 2015 zaitor@opensuse.org
- Update to version 0.28.1:
  + Bug fixes and binding updates.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 0.28.0:
  + Binding updates.
* Thu Mar 19 2015 dimstar@opensuse.org
- Update to version 0.27.2:
  + Bug fixes and binding updates.
* Wed Jan 28 2015 zaitor@opensuse.org
- Update to version 0.27.1:
  + Print compiler messages in color.
  + Add clutter-gdk-1.0 bindings.
  + Add clutter-gst-3.0 bindings.
  + Add clutter-x11-1.0 bindings.
  + Add rest-extras-0.7 bindings.
  + Bug fix and binding updates.
- Bump vala_version to 0.28, vala_libversion to 0_28 and
  vala_priority to 28, following upstreams changes.
* Fri Jan 16 2015 zaitor@opensuse.org
- Update to version 0.26.2:
  + Bug fixes and binding updates.
* Thu Nov 13 2014 olaf@aepfle.de
- Add attr to ghost entries in file list to fix build in SLE_11
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 0.26.1:
  + Bug fixes and binding updates.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 0.26.0:
  + Bug fix and binding updates.
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 0.25.4:
  + Add option --vapi-comments.
  + Bug fixes and binding updates.
  + Updated translations.
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 0.25.3:
  + Bug fixes and binding updates.
* Sun Aug 24 2014 zaitor@opensuse.org
- Update to version 0.25.2:
  + Report warning for private struct fields.
  + Replace webkit2gtk-3.0 bindings with webkit2gtk-4.0 bindings.
  + Always build vapigen.
  + Bug fixes and binding updates.
* Wed Jul 23 2014 dimstar@opensuse.org
- Update to version 0.25.1:
  + Support explicit interface method implementation.
  + Support (unowned type)[] syntax.
  + Support non-literal length in fixed-size arrays.
  + Mark regular expression literals as stable.
  + GIR parser updates.
  + Add webkit2gtk-3.0 bindings.
  + Add gstreamer-allocators-1.0 and gstreamer-riff-1.0 bindings.
  + Bug fixes and binding updates.
- Bump vala_version to 0.26, vala_libversion to 0_26 and
  vala_priority to 26, following upstreams changes.
- Correct update-alternatives usage.
- Add pkgconfig(vapigen) Provides: due to the correct usage of
  update-alternatives, %%{_datadir}/pkgconfig/vapigen.pc is now only
  as %%ghost in the package; this results in the file not being
  processed for Requires and Provides.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 0.24.0:
  + Bug fixes and binding updates.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 0.23.3:
  + Bug fixes and binding updates.
* Wed Feb  5 2014 dimstar@opensuse.org
- Update to version 0.23.2:
  + Bind GDK event structures as compact classes.
  + Switch gdk-x11-3.0 bindings to .gir.
  + Switch librsvg-2.0 bindings to .gir.
  + Bug fixes and binding updates.
* Sun Dec 22 2013 zaitor@opensuse.org
- Update to version 0.23.1:
  + Switch libnotify bindings to .gir.
  + Add libpeas-gtk-1.0 bindings.
  + Add xcb-icccm bindings.
- Change vala_version to 0.24 and vala_priority to 24, following
  upstreams versioning.
* Wed Nov 13 2013 dimstar@opensuse.org
- Update to version 0.22.1 (bnc#849913):
  + Support chain up to constructv functions.
  + Bug fixes and binding updates.
* Mon Sep 23 2013 zaitor@opensuse.org
- Update to version 0.22.0:
  + Support chain up to constructv functions.
  + Bug fixes and binding updates.
* Fri Sep 13 2013 dimstar@opensuse.org
- Update to version 0.21.2:
  + Recognize ref/unref functions in .gir files.
  + Add geocode-glib bindings.
  + Bug fixes and binding updates.
* Fri Aug  2 2013 dimstar@opensuse.org
- Update to version 0.21.1:
  + Support \uXXXX escape sequences.
  + Support specifying vfunc order in interfaces to define ABI.
  + Support GTK+ widget templates.
  + Bug fixes and binding updates.
- Change vala_version to 0.22 and vala_priority to 22, following
  upstreams versioning.
* Mon Apr  8 2013 dimstar@opensuse.org
- Update to version 0.20.1:
  + Bug fixes.
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 0.20.0:
  + Bug fixes and binding updates.
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 0.19.0:
  + Support scope = "async" attribute for parameters.
  + Add --api-version option.
  + Add atspi-2 bindings.
  + Add gstreamer-rtsp-server-1.0 bindings.
  + Bug fixes and binding updates.
* Wed Nov 14 2012 dimstar@opensuse.org
- Update to version 0.18.1:
  + Bug fixes and binding updates.
* Wed Oct 17 2012 dimstar@opensuse.org
- Add xsltproc BuildRequires: Needed to to build the devhelp books.
- Drop xz BuildRequires, as it now comes for free in the build
  system.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 0.18.0:
  + Bug fixed: bgo#683922.
* Sun Sep 16 2012 dimstar@opensuse.org
- Update to version 0.17.7:
  + Add libgnome-menu-3.0 bindings.
  + Bug fixes and binding updates.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 0.17.6:
  + Bug fixes and binding updates.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 0.17.5:
  + Support subclassing of GLib.Source.
  + Switch pango bindings to .gir.
  + Add gstreamer-1.0 core bindings.
  + Add gst-plugins-base-1.0 bindings.
  + Add gobject-introspection-1.0 bindings.
  + Bug fixes and binding updates.
* Mon Aug  6 2012 dimstar@opensuse.org
- Update to version 0.17.4:
  + Warn when accessing static members with an instance reference.
  + Recompute length when casting between array types.
  + Support [GenericAccessors] attribute for interfaces.
  + Deprecate implicit .begin for async methods.
  + Drop Dova profile.
  + Drop POSIX profile.
  + Bug fixes and binding updates.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 0.17.3:
  + Require and target GLib >= 2.18.
  + Support async creation methods.
  + Bug fixes and binding updates.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 0.17.2:
  + Bug fixes and binding updates.
* Sun Jun 24 2012 dimstar@opensuse.org
- Update to version 0.17.1:
  + Improve assertion messages.
  + Add --enable-gobject-tracing commandline option.
  + Bug fixes and binding updates.
* Sun Jun 24 2012 dimstar@opensuse.org
- Update to version 0.17.0:
  + Support simple method-level profiling.
  + Add VALA_CHECK_MODULES and VALA_PROG_VAPIGEN to vala.m4.
  + Bug fixes and binding updates
* Sun Jun 24 2012 zaitor@opensuse.org
- Update to version 0.16.1:
  + Bug fixes and binding updates.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 0.16.0:
  + Add udisks2 bindings.
  + Bug fixes and binding updates.
* Sat Feb 25 2012 zaitor@opensuse.org
- Update to version 0.15.2:
  + Switch poppler-glib bindings to .gir.
  + Many bug fixes and binding updates.
* Fri Jan 27 2012 vuntz@opensuse.org
- Update to version 0.15.1:
  + Support arrays with nullable elements.
  + Add <doc> support to .gir reader and writer.
  + Switch clutter-gtk-1.0 bindings to .gir.
  + Switch gio-2.0 bindings to .gir.
  + Add cogl-pango-1.0 bindings.
  + Add gdl-3.0 bindings.
  + Add libnl-3.0 bindings.
  + Add packagekit-glib2 bindings.
  + Add xtst bindings.
  + Many bug fixes and binding updates.
* Tue Dec  6 2011 dimstar@opensuse.org
- Update to version 0.15.0:
  + Manage memory of GQueue elements.
  + Switch atk bindings to .gir.
  + Switch gdk-pixbuf-2.0 bindings to .gir.
  + Switch gdk-3.0 bindings to .gir.
  + Add libwnck-3.0 bindings.
  + Many bug fixes and binding updates.
- Change the various %%define in spec file to use 0.16 version.
* Wed Nov 30 2011 dimstar@opensuse.org
- Update to version 0.14.1:
  + Add libwnck-3.0 bindings.
  + Many bug fixes and binding updates.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that...
  See bnc#697467 for more details.
* Sun Sep 18 2011 vuntz@opensuse.org
- Update to version 0.14.0:
  + Bug fixes and binding updates.
* Wed Sep  7 2011 vuntz@opensuse.org
- Update to version 0.13.4:
  + Switch gudev-1.0 bindings to .gir.
  + Switch mx-1.0 bindings to .gir.
  + Many bug fixes and binding updates.
- Drop vala-markupparser-fix.patch: fixed upstream.
* Mon Sep  5 2011 vuntz@opensuse.org
- Add vala-markupparser-fix.patch: this fixes GMarkupParser
  bindings, which enables a new fillmode-lombard to build.
* Mon Aug 22 2011 dimstar@opensuse.org
- Update to version 0.13.3:
  + Switch pangocairo bindings to .gir.
  + Bug fixes.
* Wed Aug 17 2011 dimstar@opensuse.org
- Update to version 0.13.2:
  + Enable flow analysis for out parameters.
  + Refactor attribute handling.
  + Add gedit-3.0 bindings.
  + Add gtksourceview-3.0 bindings.
  + Add rest-0.7 bindings.
  + Add vte-2.90 bindings.
  + Switch clutter-1.0 bindings to .gir.
  + Switch libgdata bindings to .gir.
  + Switch libsoup bindings to .gir.
  + Many bug fixes and binding updates.
* Wed Jul  6 2011 vuntz@opensuse.org
- Update to version 0.13.1:
  + Many bug fixes and binding updates.
* Fri Jun 24 2011 dimstar@opensuse.org
- Update to version 0.13.0:
  + More refactoring in the code generator.
  + Improvements to the .gir reader.
  + Switch JSON-GLib bindings to .gir.
  + Drop deprecated support for D-Bus GLib in favor of GDBus.
  + Many bug fixes and binding updates.
- Adjust vala_version, vala_libversion and priority for 0.13.
* Thu Jun  2 2011 dimstar@opensuse.org
- Update to version 0.12.1:
  + Many bug fixes and binding updates.
* Mon Apr  4 2011 dimstar@opensuse.org
- Update to version 0.12.0:
  + Add get_next_char to string class.
  + Many bug fixes and binding updates.
- Changes from version 0.11.7:
  + Add support for async signal handlers.
  + More refactoring in the code generator.
  + Improvements to the .gir writer.
  + Many bug fixes and binding updates.
- Changes from version 0.11.6:
  + Add parse and try_parse methods to boolean and numeric types.
  + Add clutter-gtk-1.0 bindings.
  + Add pixmap-1 bindings.
  + Many bug fixes and binding updates.
- Changes from version 0.11.5:
  + Add last_index_of and last_index_of_char to string class.
  + More refactoring in the code generator.
  + Improvements to the .gir writer.
  + Many bug fixes and binding updates.
- Changes from version 0.11.4:
  + Add index_of, index_of_char, and char_count to string class.
  + Many bug fixes and binding updates.
- Changes from version 0.11.3:
  + Support BusName sender parameter in GDBus servers.
  + More refactoring in the code generator.
  + Many bug fixes and binding updates.
- Changes from version 0.11.2:
  + Update libnotify bindings to 0.7.0.
  + Improvements to the .gir reader.
  + Bug fixes and binding updates.
- Changes from version 0.11.1:
  + Require and target GLib >= 2.16.
  + Guard access to out parameters to allow null arguments.
  + Add support for local constants.
  + Support file descriptor passing with GDBus.
  + Support cached property values in GDBus clients.
  + Support Cancellable parameter in GDBus clients.
  + Support no-reply methods in GDBus clients and servers.
  + More refactoring in the code generator.
  + Many bug fixes and binding updates.
- Changes from version 0.11.0:
  + Use byte indices for strings.
  + Use uint8[] for binary data in bindings.
  + Add support for parallel compilation.
  + Improve compiler performance.
  + More refactoring in the code generator.
  + Many bug fixes and binding updates.
- Drop vala-bgo638902-shotwell-fix.patch: fixed upstream.
* Sun Jan  9 2011 vuntz@opensuse.org
- Change the test for update-alternatives in %%postun to not check
  if the package is still installed, but to check if the binary is
  still there, to handle package renamings.
* Sun Jan  9 2011 vuntz@opensuse.org
- Add vala-bgo638902-shotwell-fix.patch to fix a build issue with
  shotwell 0.8.0. Based on patch from git.
* Tue Dec 28 2010 dimstar@opensuse.org
- Update to version 0.10.2:
  + Bug fixes and binding updates.
* Thu Nov 18 2010 vuntz@opensuse.org
- Update to version 0.10.1:
  + Remove outdated GTK+ 3 bindings.
  + Many bug fixes and binding updates.
* Sat Sep 18 2010 vuntz@opensuse.org
- Update to version 0.10.0:
  + Port GIR parser and writer to GIR version 1.2.
  + Update GLib bindings to 2.26 branch.
  + Bug fixes.
* Sat Sep  4 2010 dimstar@opensuse.org
- Update to version 0.9.8:
  + Add --fatal-warnings commandline option.
  + Deprecate string.len () in favor of string.length.
  + Deprecate use of D-Bus GLib in favor of GDBus.
  + Many bug fixes and binding updates.
* Tue Aug 24 2010 vuntz@opensuse.org
- Update summaries.
- Merge devel package in main package since vala is really a build
  tool. Add appropriate Provides/Obsoletes tags. Note that we'd
  want the vala-devel Provides in all cases since it's a build
  tool.
- Split the library in a libvala-0_10-0 subpackage, and split its
  development files in libvala-0_10-devel.
- Remove weird sed lines that were changing libtool.
- Add update-alternatives Requires(post/postun).
- Fix update-alternatives setup to use slaves, and only get a main
  alternative on which everything else depends.
* Fri Aug 20 2010 dimstar@opensuse.org
- Update to version 0.9.7:
  + Fix regression introduced by codegen refactoring.
* Wed Aug 18 2010 dimstar@opensuse.org
- Update to version 0.9.6:
  + Drop deprecated support for assigning to construct properties.
  + Some refactoring in the code generator.
  + Bug fixes in bindings and vapigen.
* Mon Aug  9 2010 dimstar@opensuse.org
- Update to version 0.9.5:
  + Add version suffix to support parallel installation.
  + Define VALA_X_Y according to compiler version.
  + Enable version header by default.
  + Add vala.m4 with VALA_CHECK_PACKAGES macro.
  + Add gedit-2.20 bindings
  + Add tokyocabinet bindings
  + Various improvements to the Dova profile.
  + Many bug fixes and binding updates.
- The non-versioned binaries are handled with update-alternatives,
  so that we have an easy play with upcoming versions, allowing to
  install them in parallel.
- Add fdupes BuildRequires and link duplicate files in /usr/share.
* Fri Aug  6 2010 vuntz@opensuse.org
- Update to version 0.9.4:
  + Append documentation comments to generated C files.
  + Skip <doc> tags in .gir files.
  + Various improvements to the Dova profile.
  + Many bug fixes and binding updates.
* Mon Jul 26 2010 dimstar@opensuse.org
- Update to version 0.9.3:
  + Support newlines in double quoted string literals.
  + Add experimental support for main blocks.
  + Add experimental vala tool to compile and run code.
  + Initial support for generic delegates.
  + Support using GClosure for delegate parameters.
  + Support GBoxed-based memory management.
  + Improvements to the .gir reader and writer.
  + Various improvements to the Dova profile.
  + Many bug fixes and binding updates.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 0.9.2:
  + Initial support for GDBus-based clients and servers.
  + Support implicit and explicit GVariant casts.
  + Add support for [Deprecated] attribute.
  + Add GenericArray as alternative binding to GPtrArray.
  + Add gdk-pixbuf-3.0, gdk-3.0, gdk-x11-3.0, and gtk+-3.0
    bindings.
  + Updates to the GLib bindings.
  + Many bug fixes.
- Changes from version 0.9.1:
  + Support constants in enums.
  + Deprecate +=/-= syntax to connect/disconnect signal handlers.
  + Add experimental support for Dova profile.
  + Update Genie parser.
  + Add clutter-gst-1.0 bindings.
  + Add gdu and gdu-gtk bindings.
  + Add libesmtp bindings.
  + Add mx-1.0 bindings.
  + Add orc-0.4 bindings.
  + Add rest-extras-0.6 bindings.
  + Updates to the GLib, GStreamer, Linux, SQLite, and other
    bindings
  + Many bug fixes.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 0.8.1:
  + Support constants in enums.
  + Add clutter-gst-1.0 bindings
  + Add gdu and gdu-gtk bindings.
  + Many bug fixes and binding updates.
* Wed Mar 31 2010 vuntz@opensuse.org
- Update to version 0.8.0:
  + Infer type arguments when calling generic methods.
  + Support `in' operator for arrays.
  + Add experimental support for regular expression literals.
  + Add experimental support for chained relational expressions.
  + Add va_list support.
  + Add clutter-gtk-0.10 bindings.
  + Add gdl-1.0 bindings.
  + Add gstreamer-app-0.10 bindings.
  + Add gstreamer-cdda-0.10 bindings.
  + Add gudev-1.0 bindings.
  + Add libgda-report-4.0 bindings.
  + Add libgvc (graphviz) bindings.
  + Add purple bindings.
  + Many bug fixes and binding updates.
* Fri Feb  5 2010 lmedinas@opensuse.org
- Update to version 0.7.10:
  + Support coalescing operator ??.
  + Support to_string and bitwise complement with enums.
  + Return handler id when connecting signal handlers.
  + Support struct comparison.
  + Support constructor chaining in structs.
  + Enforce protected member restrictions.
  + Improve performance of flow analysis.
  + Support automatic line continuations in Genie.
  + Improvements to the .gir reader and writer.
  + Add --enable-mem-profiler commandline option.
  + Many bug fixes and binding updates.
- Drop return-fix.patch: fixed upstream.
* Sun Dec 20 2009 vuntz@opensuse.org
- Update to version 0.7.9:
  + Support array and string slicing.
  + Add --symbols commandline option.
  + Add avahi-gobject bindings.
  + Add ccss-1 bindings.
  + Add libarchive bindings.
  + Add libmagic bindings.
  + Add readline bindings.
  + Add twitter-glib-1.0 bindings.
  + Many bug fixes and binding updates.
- Remove check for old version of openSUSE.
* Fri Nov 27 2009 dimstar@opensuse.org
- Update to version 0.7.8:
  + Support constructor chain up to GObject using Object (...).
  + Add syntax for string templates.
  + Support (!) non-null casts.
  + Many bug fixes and binding updates.
- Fixes from version 0.7.6:
  + Support `using' directives inside namespaces.
  + Use const only for immutable structs.
  + Support string marshalling for enums in D-Bus
- Fixes from version 0.7.5:
  + Update Genie parser
  + Add libgda-4.0 bindings
  + Many bug fixes for closures and async methods.
  + Add support for closures.
  + Improve support for asynchronous methods.
  + Support async methods in D-Bus servers.
  + Add clutter-1.0 bindings
  + Add GVariant, GSettings, and dconf bindings
  + Add linux, libnl-1, and libasound bindings
  + Add gnutls bindings
  + Add librest bindings
  + Many bug fixes and binding updates.
- Rebase return-fix.patch
- Drop vala-0.3.3-implicit-fortify-decl.patch, upstream fixed.
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Aug  3 2009 dominique-obs@leuenberger.net
- Update to version 0.7.5:
  + Add support for static properties.
  + Add support for delegate properties.
  + Support virtual default handler for signals.
  + Add limited support for derived compact classes.
  + Add libgdata bindings
  + Add libusb-1.0 bindings
  + Many bug fixes and binding updates.
* Mon Jul 27 2009 dominique-obs@leuenberger.net
- Update to version 0.7.4:
  + Way too many changes since 0.3.3. See NEWS for details.
- Refactored retry-fix.patch. Patch rejected upstream, as the .c
  files are generated ones.
- Remove INSTALL from %%%%doc to fix a rpmlint warning.
* Tue Oct 14 2008 crrodriguez@suse.de
- fix implicit-fortify-decl errors
- correct -devel package requires
* Fri Sep 12 2008 mauro@suse.de
- Added return-fix.patch to fix the error " Program returns random
  data in a function".
* Fri Jul 25 2008 mauro@suse.de
- initial SUSE package
